@@ -27,14 +27,14 @@
 get_centroids <- function(landscape, directions = 8, cell_center = FALSE,
                           return_sp = FALSE, verbose = TRUE) {
 
+    landscape <- landscape_as_list(landscape)
+
     if (return_sp) {
 
-        crs <- raster::crs(landscape)
+        crs <- raster::crs(landscape[[1]])
 
     }
 
-    landscape <- landscape_as_list(landscape)
-
     result <- lapply(X = landscape,
                      FUN = get_centroids_calc,
                      directions = directions,
